"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.serializers = exports.DEFAULT_SEPARATOR = exports.arrayFloatSerializer = exports.arrayIntSerializer = exports.arrayStringSerializer = void 0;
const join = (value, separator) => value.join(separator);
const split = (value, separator) => (value === null || value === void 0 ? void 0 : value.split(separator).filter((str) => str.trim() !== '')) || [];
const intSerializer = {
    deserialize: (value) => {
        if (value === null) {
            return value;
        }
        const num = parseInt(value, 10);
        return Number.isNaN(num) ? null : num;
    },
    serialize: (value) => String(value),
};
const floatSerializer = {
    deserialize: (value) => {
        if (value === null) {
            return value;
        }
        const num = parseFloat(value);
        return Number.isNaN(num) ? null : num;
    },
    serialize: (value) => String(value),
};
const stringSerializer = {
    deserialize: (value) => value === null ? null : String(value),
    serialize: (value) => String(value),
};
const arrayStringSerializer = (separator) => ({
    deserialize: (value) => split(value, separator),
    serialize: (value) => value ? join(value, separator) : null,
});
exports.arrayStringSerializer = arrayStringSerializer;
const arrayIntSerializer = (separator) => ({
    deserialize: (value) => split(value, separator).map(intSerializer.deserialize),
    serialize: (value) => value ? join(value, separator) : null,
});
exports.arrayIntSerializer = arrayIntSerializer;
const arrayFloatSerializer = (separator) => ({
    deserialize: (value) => split(value, separator).map(floatSerializer.deserialize),
    serialize: (value) => value ? join(value, separator) : null,
});
exports.arrayFloatSerializer = arrayFloatSerializer;
const dateSerializer = (locale = 'en-us', timeZone = 'UTC') => ({
    deserialize: (value) => value ? new Date(value) : new Date(),
    serialize: (value) => value === null || value === void 0 ? void 0 : value.toLocaleDateString(locale, { timeZone }),
});
const booleanSerializer = {
    deserialize: (value) => value === '1',
    serialize: (value) => (value ? '1' : '0'),
};
exports.DEFAULT_SEPARATOR = '_';
exports.serializers = {
    arrayFloat: (0, exports.arrayFloatSerializer)(exports.DEFAULT_SEPARATOR),
    arrayInt: (0, exports.arrayIntSerializer)(exports.DEFAULT_SEPARATOR),
    arrayString: (0, exports.arrayStringSerializer)(exports.DEFAULT_SEPARATOR),
    boolean: booleanSerializer,
    date: dateSerializer,
    float: floatSerializer,
    int: intSerializer,
    string: stringSerializer,
};
