/// <reference types="react" resolution-mode="require"/>
import { StoreApi, UseBoundStore } from 'zustand';
import { InnerNamespace, NamespaceValues, StoreState } from './middleware.js';
import { Serializer } from './serializers.js';
import type { PartialDeep } from 'type-fest';
export declare const DEFAULT_NAMESPACE = "default";
export declare const StoreContext: import("react").Context<StoreApi<StoreState<any, any>> | null>;
export interface Parameter<V = any> {
    readonly name: string;
    readonly serializer: Serializer<V>;
    readonly skipValue: (value?: V, initialValue?: V) => boolean;
}
export interface MappedParameter extends Parameter {
    readonly path: readonly string[];
}
export interface Config {
    readonly [propName: string]: this | this[] | (() => Parameter);
}
export interface MappedConfig {
    readonly [queryParameter: string]: MappedParameter;
}
export type RouterOptions = Record<string, unknown>;
export interface HistoryManagement {
    /** the initial search string (e.g. ?query=test), contains the questionsmark */
    readonly initialSearch: () => string | URLSearchParams;
    readonly push: (queryObject: Record<string, string>, options?: RouterOptions) => Promise<unknown>;
    readonly replace: (queryObject: Record<string, string>, options?: RouterOptions) => Promise<unknown>;
}
export declare const createGeschichte: <T extends Record<string, unknown>, N extends InnerNamespace<T>>(historyInstance: HistoryManagement) => import("zustand/traditional").UseBoundStoreWithEqualityFn<Omit<Omit<StoreApi<StoreState<T, N>>, "subscribe"> & {
    subscribe: {
        (listener: (selectedState: StoreState<T, N>, previousSelectedState: StoreState<T, N>) => void): () => void;
        <U>(selector: (state: StoreState<T, N>) => U, listener: (selectedState: U, previousSelectedState: U) => void, options?: {
            equalityFn?: ((a: U, b: U) => boolean) | undefined;
            fireImmediately?: boolean | undefined;
        } | undefined): () => void;
    };
}, "setState"> & {
    setState<A extends string | {
        type: unknown;
    }>(partial: StoreState<T, N> | Partial<StoreState<T, N>> | ((state: StoreState<T, N>) => StoreState<T, N> | Partial<StoreState<T, N>>), replace?: boolean | undefined, action?: A | undefined): void;
}>;
type InitialValuesProvider<T> = T | (() => T);
export declare const useStore: <V extends Record<string, unknown>, N extends InnerNamespace<V>>() => UseBoundStore<StoreApi<StoreState<V, N>>>;
export declare const useBatchQuery: <N extends InnerNamespace<Record<string, unknown>>>() => {
    batchPushState: <Keys extends keyof N>(ns: Keys[], fn: (...args: (N[Keys]["values"] | undefined)[]) => void, routerOptions?: RouterOptions | undefined) => Promise<unknown>;
    batchReplaceState: <Keys_1 extends keyof N>(ns: Keys_1[], fn: (...args: (N[Keys_1]["values"] | undefined)[]) => void, routerOptions?: RouterOptions | undefined) => Promise<unknown>;
};
export declare const factoryParameters: <T extends Record<string, unknown>, N extends InnerNamespace<T>>(config: Config, defaultInitialValues?: InitialValuesProvider<T>, ns?: string) => {
    useQuery: () => {
        createQuery: (customValues?: PartialDeep<T> | undefined) => {};
        createQueryString: (customValues?: PartialDeep<T> | undefined) => string;
        initialValues: T;
        pushState: (state: (state: T) => void, options?: Record<string, unknown>) => Promise<unknown>;
        replaceState: (state: (state: T) => void, options?: Record<string, unknown>) => Promise<unknown>;
        resetPush: () => void;
        resetReplace: () => void;
        values: T;
    };
    createQueryString: (values: PartialDeep<T>, initialValues?: PartialDeep<T> | null | undefined) => string;
    parseQueryString: (query: string, initialValues?: PartialDeep<T> | null | undefined) => Partial<T>;
};
export type InferNamespaceValues<F extends ReturnType<typeof factoryParameters>['useQuery']> = NamespaceValues<ReturnType<F>['values']>;
export {};
